==> certmanager-model-v1alpha2-6.8.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/CertificatePrivateKeyFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CertificatePrivateKeyFluent<A extends CertificatePrivateKeyFluent<A>> extends BaseFluent<A>{
  public CertificatePrivateKeyFluent() {
  }
  public CertificatePrivateKeyFluent(CertificatePrivateKey instance) {
    instance = (instance != null ? instance : new CertificatePrivateKey());

    if (instance != null) {
      this.withRotationPolicy(instance.getRotationPolicy());
      this.withRotationPolicy(instance.getRotationPolicy());
    }
  }
  private String rotationPolicy;
  public String getRotationPolicy() {
    return this.rotationPolicy;
  }
  public A withRotationPolicy(String rotationPolicy) {
    this.rotationPolicy=rotationPolicy; return (A) this;
  }
  public boolean hasRotationPolicy() {
    return this.rotationPolicy != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CertificatePrivateKeyFluent that = (CertificatePrivateKeyFluent) o;
    if (!java.util.Objects.equals(rotationPolicy, that.rotationPolicy)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(rotationPolicy,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (rotationPolicy != null) { sb.append("rotationPolicy:"); sb.append(rotationPolicy); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> certmanager-model-v1alpha2-6.9.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/CertificatePrivateKeyFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class CertificatePrivateKeyFluent<A extends CertificatePrivateKeyFluent<A>> extends BaseFluent<A>{
  public CertificatePrivateKeyFluent() {
  }
  
  public CertificatePrivateKeyFluent(CertificatePrivateKey instance) {
    this.copyInstance(instance);
  }
  private String rotationPolicy;
  
  protected void copyInstance(CertificatePrivateKey instance) {
    instance = (instance != null ? instance : new CertificatePrivateKey());
  
    if (instance != null) {
        this.withRotationPolicy(instance.getRotationPolicy());
        this.withRotationPolicy(instance.getRotationPolicy());
      }
  }
  
  public String getRotationPolicy() {
    return this.rotationPolicy;
  }
  
  public A withRotationPolicy(String rotationPolicy) {
    this.rotationPolicy=rotationPolicy; return (A) this;
  }
  
  public boolean hasRotationPolicy() {
    return this.rotationPolicy != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CertificatePrivateKeyFluent that = (CertificatePrivateKeyFluent) o;
    if (!java.util.Objects.equals(rotationPolicy, that.rotationPolicy)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(rotationPolicy,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (rotationPolicy != null) { sb.append("rotationPolicy:"); sb.append(rotationPolicy); }
    sb.append("}");
    return sb.toString();
  }
  

}
